package miniblog

import groovy.text.SimpleTemplateEngine
import groovy.xml.MarkupBuilder

import java.text.SimpleDateFormat

class Renderer  {

  static URL = 'http://localhost:8080/miniblog/'

  static dateFormatter = [
    'us' : new SimpleDateFormat( "EEE, dd MMM yyyy HH:mm:ss Z", Locale.US ),
    'ja' : new SimpleDateFormat( "yyyy/MM/dd HH:mm:ss" )
  ]

  static HTML =
    """<html>
         <head>
           <title>GroovyŃ~juO</title>
           <link rel="stylesheet" type="text/css" href="miniblog.css" />
         </head>
         <body>
           <h2>GroovyŃ~juO</h2>
           <div class="rss"><a href="rss.groovy">RSS</a></div>
           <%= body %>
         </body>
       </html>"""

  static RSS =
    """<?xml version="1.0" encoding="<%= encoding %>"?>
         <rss version="2.0">
           <channel>
             <title><%= title %></title>
             <link><%= link %></link>
             <description><%= desc %></description>
             <language>ja-jp</language>
             <copyright>Copyright (c) <%= year %> <%= name %> All rights reserved.</copyright>
             <pubDate><%= date %></pubDate>
             <image />
             <%= items %>
           </channel>
         </rss>"""

  static loginForm =
    """<form action="login.groovy" method="post">
         <table>
           <tr><td>[U[</td><td><input type="text" name="name" size="20" value="<%= name %>" /></td></tr>
           <tr><td>pX[h</td><td><input type="password" name="pass1" size="20" value="" /></td></tr>
           <tr><td>pX[hmF</td><td><input type="password" name="pass2" size="20" value="" /></td></tr>
           <tr><td colspan="2">
             <input type="submit" name="login"  value="OCEo^" />
             <input type="submit" name="delete" value="폜" onclick="javascript:return confirm('폜܂?')" />
           </td></tr>
         </table>
       </form>
       <p class="display"><%= display %></p>"""

  static postForm =
    """<p>OC̃[U[ : <%= name %> <a href="logout.groovy">OAEg</a></p>
       <form method="post">
         <input type="text" name="message" size="50" value="<%= defaultMessage %>"
             onfocus="javascript:if (this.value == '<%= defaultMessage %>') this.value=''"
             onblur="javascript:if (this.value.length < 1) this.value='<%= defaultMessage %>'" />
         <input type="submit" name="post" value="e" />
       </form>
       <p class="display"><%= display %></p>"""


  def renderTemplate( template, data ) {
    def te = new SimpleTemplateEngine()
    te.createTemplate( template ).make( data ).toString()
  }

  def renderMessages( messages )  {

    def html = new StringWriter();
    def builder = new MarkupBuilder( html )

    builder.table {
      if ( messages?.size )  {
        builder.thead {
          caption( "${messages.size}̓e܂" )
          tr {
            th( '[U[' )
            th( 'bZ[W' )
            th( 'e' )
          }
        }
        builder.tbody {
          messages.each { miniblog ->
            builder.tr() {
              td {
                a( href:(Renderer.URL + 'post.groovy?name=' + miniblog.user.name ), miniblog.user.name )
              }
              td( miniblog.message )
              td( Renderer.dateFormatter['ja'].format( miniblog.dt ) )
            }
          }
        }
      } else {
        builder.tr {
          td( 'e͂܂' )
        }
      }
    }

    html.toString()

  }

  def renderItems( messages )  {

    def xml = new StringWriter()
    def builder = new MarkupBuilder( xml )

    messages.each { miniblog ->
      builder.item() {
        title( miniblog.message )
        link ( Renderer.URL )
        description( '[' + miniblog.user.name + '] ' + miniblog.message )
        category( miniblog.user.name )
        pubDate( Renderer.dateFormatter['us'].format( miniblog.dt ) )
      }
    }

    xml.toString()

  }

}